@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Index.py,v 1.10 2000/04/14 11:18:50 fredgo Exp $
+# $Id: Index.py,v 1.11 2000/05/11 09:03:45 fredgo Exp $
 
 ''' Main index containing the columned view of the entries '''
 
@@ -178,7 +178,8 @@ class Index (Connector.Publisher):
         
         if info == Mime.KEY:
             # must return a set of keys
-            data = join (map (lambda e: str (e.key.base) + '\0' + str (e.key.key), entries), '\n')
+            data = join (map (lambda e: str (e.key.base or '') + '\0' +
+                              str (e.key.key), entries), '\n')
             selection.set (selection.target, 8, data)
             
         elif info == Mime.ENTRY:
