@@ -19,12 +19,12 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: pybconvert.py,v 1.1.1.1 1999/11/22 13:29:35 fredgo Exp $
+# $Id: pybconvert.py,v 1.2 2000/03/24 10:13:22 fredgo Exp $
 
 import os, sys, string
 
 if len (sys.argv) < 3 or len (sys.argv) > 4:
-    print "usage: pybconvert <source>..<target> <input> [output]"
+    print _("usage: pybconvert <source>..<target> <input> [output]")
     sys.exit (1)
 
 
@@ -33,7 +33,7 @@ format = sys.argv [1]
 try:
     source, target = string.split (format, '..')
 except:
-    print "pybconvert: bad conversion format"
+    print _("pybconvert: bad conversion format")
     sys.exit (1)
 
 
